@@ -6,6 +6,7 @@ import zipfile
 import pytest
 from shapely.geometry import Polygon
 
+import pygeoogc
 from pygeoogc import WFS, WMS, ArcGISRESTful, MatchCRS, RetrySession, ServiceURL, utils
 
 DEF_CRS = "epsg:4326"
@@ -32,6 +33,7 @@ def geometry_urb():
     )
 
 
+@pytest.mark.flaky(max_runs=3)
 def test_restful(geometry_nat):
     wbd2 = ArcGISRESTful(base_url=f"{ServiceURL().restful.wbd}/1")
     print(wbd2)
@@ -57,6 +59,7 @@ def test_restful(geometry_nat):
     )
 
 
+@pytest.mark.flaky(max_runs=3)
 def test_wms(geometry_nat):
     url_wms = ServiceURL().wms.fws
 
@@ -64,9 +67,10 @@ def test_wms(geometry_nat):
     wms = WMS(url_wms, layers="0", outformat="image/tiff", crs=DEF_CRS)
     print(wms)
     r_dict = wms.getmap_bybox(geometry_nat.bounds, 20, DEF_CRS)
-    assert sys.getsizeof(r_dict["0_0"]) == 12536763
+    assert sys.getsizeof(r_dict["0_dd_1"]) == 12536763
 
 
+@pytest.mark.flaky(max_runs=3)
 def test_wfsbybox(geometry_urb):
     url_wfs = ServiceURL().wfs.fema
     wfs = WFS(
@@ -82,6 +86,7 @@ def test_wfsbybox(geometry_urb):
     assert len(r.json()["features"]) == 628
 
 
+@pytest.mark.flaky(max_runs=3)
 def test_wfsbyid():
     wfs = WFS(
         ServiceURL().wfs.waterdata,
@@ -95,6 +100,7 @@ def test_wfsbyid():
     assert st.json()["numberMatched"] == 1
 
 
+@pytest.mark.flaky(max_runs=3)
 def test_fspec1():
     wfs = WFS(
         ServiceURL().wfs.waterdata,
@@ -108,9 +114,9 @@ def test_fspec1():
     assert st.json()["numberMatched"] == 1
 
 
-def test_vsplit(geometry_urb):
-    bboxs = utils.vsplit_bbox(geometry_urb.bounds, 10)
-    assert bboxs[-1][0] == 1803
+def test_decompose(geometry_urb):
+    bboxs = utils.bbox_decompose(geometry_urb.bounds, 10)
+    assert bboxs[0][-1] == 2828
 
 
 def test_matchcrs(geometry_urb):
@@ -170,3 +176,9 @@ def test_urls():
         and urls.http.ssebopeta
         == "https://edcintl.cr.usgs.gov/downloads/sciweb1/shared/uswem/web/conus/eta/modis_eta/daily/downloads"
     )
+
+
+def test_show_versions():
+    f = io.StringIO()
+    pygeoogc.show_versions(file=f)
+    assert "INSTALLED VERSIONS" in f.getvalue()
